\name{makeProbePackage}
\alias{makeProbePackage}
\title{Make a package with probe sequence related data for microarrays}
\description{Make a package with probe sequence related data for microarrays}
\usage{
makeProbePackage(arraytype,
    importfun = "getProbeDataAffy",
    maintainer,
    version,
    pkgname = NULL,
    outdir  = ".",
    force = FALSE, quiet = FALSE,
    check = TRUE, build = TRUE, unlink = TRUE, \dots)
}
\arguments{
  \item{arraytype}{Character. Name of array type (typically a vendor's
    name like "HG-U133A").}
  \item{importfun}{Character. Name of a function that can read the
    probe sequence data e.g. from a file. See
    \code{\link[matchprobes:getProbeDataAffy]{getProbeDataAffy}} for
    an example.}
  \item{maintainer}{Character. Name and email address of the maintainer.}
  \item{version}{Character. Version number for the package.}
  \item{pkgname}{Character. Name of the package. If missing, a name is
    created from \code{arraytype}.}
  \item{outdir}{Character. Path where the package is to be written.}
  \item{force}{Logical. If \code{TRUE} overrides possible warnings}
  \item{quiet}{Logical. If \code{TRUE} do not print statements on progress on the console}
  \item{check}{Logical. If \code{TRUE} call \code{R CMD check} on the package}
  \item{build}{Logical. If \code{TRUE} call \code{R CMD build} on the package}
  \item{unlink}{Logical. If \code{TRUE} unlink (remove) the \code{check}
    directory (only relevant if \code{check=TRUE})}
  \item{\dots}{Further arguments that get passed along to \code{importfun}}
}
\details{See vignette.
}
\examples{
filename <- file.path(.path.package("matchprobes"), "data", "HG-U95Av2_probe_tab.gz")
outdir   <- tempdir()
me       <- "Wolfgang Huber <w.huber@dkfz.de>"
makeProbePackage("HG-U95Av2",
                 datafile   = gzfile(filename, open="r"),
                 outdir     = outdir,
                 maintainer = me, 
                 version    = "0.0.1", 
                 force      = TRUE)
dir(outdir)
}
\keyword{IO}
\keyword{utilities}
